@@ -73,9 +73,14 @@ Account.prototype['create'] = restore_stack(function() {
         Module['_olm_create_account_random_length']
     )(this.ptr);
     var random = random_stack(random_length);
-    account_method(Module['_olm_create_account'])(
-        this.ptr, random, random_length
-    );
+    try {
+        account_method(Module['_olm_create_account'])(
+            this.ptr, random, random_length
+        );
+    } finally {
+        // clear the random buffer
+        bzero(random, random_length);
+    }
 });
 
 Account.prototype['identity_keys'] = restore_stack(function() {
@@ -140,9 +145,14 @@ Account.prototype['generate_one_time_keys'] = restore_stack(function(
         Module['_olm_account_generate_one_time_keys_random_length']
     )(this.ptr, number_of_keys);
     var random = random_stack(random_length);
-    account_method(Module['_olm_account_generate_one_time_keys'])(
-        this.ptr, number_of_keys, random, random_length
-    );
+    try {
+        account_method(Module['_olm_account_generate_one_time_keys'])(
+            this.ptr, number_of_keys, random, random_length
+        );
+    } finally {
+        // clear the random buffer
+        bzero(random, random_length);
+    }
 });
 
 Account.prototype['remove_one_time_keys'] = restore_stack(function(session) {
@@ -156,9 +166,14 @@ Account.prototype['generate_fallback_key'] = restore_stack(function() {
         Module['_olm_account_generate_fallback_key_random_length']
     )(this.ptr);
     var random = random_stack(random_length);
-    account_method(Module['_olm_account_generate_fallback_key'])(
-        this.ptr, random, random_length
-    );
+    try {
+        account_method(Module['_olm_account_generate_fallback_key'])(
+            this.ptr, random, random_length
+        );
+    } finally {
+        // clear the random buffer
+        bzero(random, random_length);
+    }
 });
 
 Account.prototype['fallback_key'] = restore_stack(function() {
@@ -172,6 +187,23 @@ Account.prototype['fallback_key'] = restore_stack(function() {
     return UTF8ToString(keys, keys_length);
 });
 
+Account.prototype['unpublished_fallback_key'] = restore_stack(function() {
+    var keys_length = account_method(
+        Module['_olm_account_unpublished_fallback_key_length']
+    )(this.ptr);
+    var keys = stack(keys_length + NULL_BYTE_PADDING_LENGTH);
+    account_method(Module['_olm_account_unpublished_fallback_key'])(
+        this.ptr, keys, keys_length
+    );
+    return UTF8ToString(keys, keys_length);
+});
+
+Account.prototype['forget_old_fallback_key'] = restore_stack(function() {
+    account_method(Module['_olm_account_forget_old_fallback_key'])(
+        this.ptr
+    );
+});
+
 Account.prototype['pickle'] = restore_stack(function(key) {
     var key_array = array_from_string(key);
     var pickle_length = account_method(
